server_client_20141211_231026

### config1 : test_redlining

Result | Function execution time | Total execution time
--- | --- | ---
Failed | 2.33638381958 sec | 4.75719308853 sec

Error message: server latency too high while sending 10000 integers

Naarad report

### Metrics

#### server1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 1.40 | 0.31 | 0.19 | 0.31 | 0.35 | 0.38 | 0.41 | 0.76 | 0.1
qps | 606.00 | 500.50 | 395.00 | 500.50 | 553.25 | 584.90 | 595.45 | 603.89 | 105.50

#### client1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
qps | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 0.0
latency | 1641.27 | 1641.27 | 1641.27 | 1641.27 | 1641.27 | 1641.27 | 1641.27 | 1641.27 | 0.0

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
server1-perf | latency | p50 lt 0.3 | 0.313
server1-perf | latency | mean lt 0.33 | 0.313847152847
server1-perf | qps | mean lt 7.0 | 500.5
server2-perf | latency | p50 lt 0.3 | None
server2-perf | latency | mean lt 0.33 | None
server2-perf | qps | mean lt 7.0 | None
server3-perf | latency | p50 lt 0.3 | None
server3-perf | latency | mean lt 0.33 | None
server3-perf | qps | mean lt 7.0 | None
client1-perf | latency | p50 lt 22.0 | 1641.273
client1-perf | latency | mean lt 35.0 | 1641.273
client1-perf | qps | mean lt 2.0 | 1.0
client2-perf | latency | p50 lt 22.0 | None
client2-perf | latency | mean lt 35.0 | None
client2-perf | qps | mean lt 2.0 | None